==> members-feign-airport4-20241231.080115-223-sources.jar: com/bizvane/members/feign/service/FlightRecordFeign.java <==
package com.bizvane.members.feign.service;

import com.bizvane.members.feign.model.bo.FlightRecordListRequestParam;
import com.bizvane.members.feign.model.bo.MbrFlightRecordAddReq;
import com.bizvane.members.feign.model.bo.MbrFlightRecordFocusReq;
import com.bizvane.members.feign.model.vo.FlightRecordVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

@FeignClient(value="${feign.client.members.name}",path="${feign.client.members.path}/flightRecord")
@Api("行程记录管理")
public interface FlightRecordFeign {

  @ApiOperation(value = "总线-新增旅客记录", notes = "总线-新增旅客记录", tags = {"总线-新增旅客记录"},httpMethod = "POST")
  @RequestMapping(value="/add", method = RequestMethod.POST)
  ResponseData<String> add(@RequestBody @Valid MbrFlightRecordAddReq bo);

  @ApiOperation(value = "小程序端新增会员行程", notes = "小程序端新增会员行程", tags = {"小程序端新增会员行程"},httpMethod = "POST")
  @RequestMapping(value="/saveApplet", method = RequestMethod.POST)
  ResponseData<String> saveApplet(@RequestBody @Valid MbrFlightRecordFocusReq bo);

  /**
   *
   * @param mbrFlightRecordCode
   * @param focusStatus 1关注，2取消关注
   * @return
   */
  @ApiOperation(value = "关注", notes = "新增航班记录详情", tags = {"新增航班记录详情接口"},httpMethod = "POST")
  @RequestMapping(value="/focus", method = RequestMethod.POST)
  ResponseData<FlightRecordVO> focus(@RequestParam("mbrFlightRecordCode") String mbrFlightRecordCode, @RequestParam("focusStatus") Integer focusStatus);

  @ApiOperation(value = "查询航班记录列表", notes = "查询航班记录列表", tags = {"查询航班记录列表接口"},httpMethod = "POST")
  @RequestMapping(value="/list", method = RequestMethod.POST)
  ResponseData<PageInfo<FlightRecordVO>> list(@RequestBody FlightRecordListRequestParam param);


  @ApiOperation(value = "新增航班记录详情", notes = "新增航班记录详情", tags = {"新增航班记录详情接口"},httpMethod = "POST")
  @RequestMapping(value="/detail", method = RequestMethod.POST)
  ResponseData<FlightRecordVO> detail(@RequestParam("mbrFlightRecordCode") @NotNull String mbrFlightRecordCode);


}

==> members-feign-airport4-20250102.023337-224-sources.jar: com/bizvane/members/feign/service/FlightRecordFeign.java <==
package com.bizvane.members.feign.service;

import com.bizvane.members.feign.model.bo.FlightRecordListRequestParam;
import com.bizvane.members.feign.model.bo.MbrFlightRecordAddReq;
import com.bizvane.members.feign.model.bo.MbrFlightRecordFocusReq;
import com.bizvane.members.feign.model.vo.FlightRecordVO;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;

@FeignClient(value="${feign.client.members.name}",path="${feign.client.members.path}/flightRecord")
@Api("行程记录管理")
public interface FlightRecordFeign {

  @ApiOperation(value = "总线-新增旅客记录", notes = "总线-新增旅客记录", tags = {"总线-新增旅客记录"},httpMethod = "POST")
  @RequestMapping(value="/add", method = RequestMethod.POST)
  ResponseData<String> add(@RequestBody @Valid MbrFlightRecordAddReq bo);

  @ApiOperation(value = "小程序端新增会员行程", notes = "小程序端新增会员行程", tags = {"小程序端新增会员行程"},httpMethod = "POST")
  @RequestMapping(value="/saveApplet", method = RequestMethod.POST)
  ResponseData<String> saveApplet(@RequestBody @Valid MbrFlightRecordFocusReq bo);

  /**
   *
   * @param mbrFlightRecordCode
   * @param focusStatus 1关注，2取消关注
   * @return
   */
  @ApiOperation(value = "关注", notes = "新增航班记录详情", tags = {"新增航班记录详情接口"},httpMethod = "POST")
  @RequestMapping(value="/focus", method = RequestMethod.POST)
  ResponseData<Boolean> focus(@RequestParam("mbrFlightRecordCode") String mbrFlightRecordCode, @RequestParam("focusStatus") Integer focusStatus);

  @ApiOperation(value = "查询航班记录列表", notes = "查询航班记录列表", tags = {"查询航班记录列表接口"},httpMethod = "POST")
  @RequestMapping(value="/list", method = RequestMethod.POST)
  ResponseData<PageInfo<FlightRecordVO>> list(@RequestBody FlightRecordListRequestParam param);


  @ApiOperation(value = "新增航班记录详情", notes = "新增航班记录详情", tags = {"新增航班记录详情接口"},httpMethod = "POST")
  @RequestMapping(value="/detail", method = RequestMethod.POST)
  ResponseData<FlightRecordVO> detail(@RequestParam("mbrFlightRecordCode") @NotNull String mbrFlightRecordCode);


}
